@@ -22,29 +22,42 @@ class PrestoIdentifierPreparer(compiler.IdentifierPreparer):
     # https://github.com/facebook/presto/blob/master/presto-parser/src/main/antlr3/com/facebook/presto/sql/parser/Statement.g
     reserved_words = frozenset([
         'all',
+        'alter',
         'and',
+        'approximate',
+        'array',
         'as',
         'asc',
+        'at',
+        'bernoulli',
         'between',
         'bigint',
         'boolean',
         'by',
         'case',
         'cast',
+        'catalog',
+        'catalogs',
         'char',
         'character',
         'coalesce',
+        'columns',
+        'confidence',
         'constraint',
         'create',
         'cross',
+        'current',
         'current_date',
         'current_time',
         'current_timestamp',
+        'date',
+        'day',
         'dec',
         'decimal',
         'desc',
         'describe',
         'distinct',
+        'distributed',
         'double',
         'drop',
         'else',
@@ -52,26 +65,41 @@ class PrestoIdentifierPreparer(compiler.IdentifierPreparer):
         'escape',
         'except',
         'exists',
+        'explain',
         'extract',
         'false',
         'first',
+        'following',
         'for',
+        'format',
         'from',
         'full',
+        'functions',
+        'graphviz',
         'group',
         'having',
+        'hour',
         'if',
         'in',
         'inner',
+        'insert',
         'int',
         'integer',
         'intersect',
+        'interval',
+        'into',
         'is',
         'join',
+        'json',
         'last',
         'left',
         'like',
         'limit',
+        'localtime',
+        'localtimestamp',
+        'logical',
+        'minute',
+        'month',
         'natural',
         'not',
         'null',
@@ -83,22 +111,51 @@ class PrestoIdentifierPreparer(compiler.IdentifierPreparer):
         'or',
         'order',
         'outer',
+        'over',
+        'partition',
+        'partitions',
+        'poissonized',
+        'preceding',
+        'range',
         'recursive',
+        'rename',
+        'replace',
+        'rescaled',
         'right',
+        'row',
+        'rows',
+        'schema',
+        'schemas',
+        'second',
         'select',
+        'show',
         'stratify',
         'substring',
+        'system',
         'table',
+        'tables',
+        'tablesample',
+        'text',
         'then',
+        'time',
+        'timestamp',
+        'to',
         'true',
+        'try_cast',
+        'type',
         'unbounded',
         'union',
+        'use',
         'using',
+        'values',
         'varchar',
         'varying',
+        'view',
         'when',
         'where',
         'with',
+        'year',
+        'zone',
     ])
 
 
